@@ -264,73 +264,4 @@ onewaygeo <- function(x, attrib){
   return(singlelines)
 }
 
-#' Aggregate ods so they become non-directional, e.g. by summing travel in both directions.
-#'
-#' Flow data often contains movement in two directions: from point A to point B
-#' and then from B to A. This can be problematic for transport planning, because
-#' the magnitude of flow along a route can be masked by flows the other direction.
-#' If only the largest flow in either direction is captured in an analysis, for
-#' example, the true extent of travel will by heavily under-estimated for
-#' OD pairs which have similar amounts of travel in both directions.
-#' Flows in both direction are often represented by overlapping lines with
-#' identical geometries (see \code{\link{flowlines}}) which can be confusing
-#' for users and are difficult to plot.
-#'
-#' This function aggregates directional flows into non-directional flows,
-#' potentially halving the number of lines objects and reducing the number
-#' of overlapping lines to zero.
-#'
-#' @param x A data frame, representing an OD matrix
-#' @param attrib A vector of column numbers or names
-#' for deciding which attribute(s) of class numeric to
-#' aggregate
-#' @param id1 Optional (it is assumed to be the first column)
-#' text string referring to the name of the variable containing
-#' the unique id of the origin
-#' @param id2 Optional (it is assumed to be the second column)
-#' text string referring to the name of the variable containing
-#' the unique id of the destination
-#'
-#' @return \code{onewayid} outputs a data.frame with rows containing
-#' results for the user-selected attribute values that have been aggregated.
-#' @export
-#' @examples
-#' data(flow)
-#' flow_oneway = onewayid(flow, attrib = 3)
-#' nrow(flow_oneway) < nrow(flow) # result has fewer rows
-#' sum(flow$All) == sum(flow_oneway$All) # but the same total flow
-#' # using names instead of index for attribute
-#' onewayid(flow, attrib = "All")
-#' # using many attributes to aggregate
-#' attrib = which(vapply(flow, is.numeric, TRUE))
-#' flow_oneway = onewayid(flow, attrib = attrib)
-#' colSums(flow_oneway[attrib]) == colSums(flow[attrib]) # test if the colSums are equal
-#' # Demonstrate the results from onewayid and onewaygeo are identical
-#' flow_oneway_geo = onewaygeo(flowlines, attrib = attrib)
-#' plot(flow_oneway$All, flow_oneway_geo$All)
-onewayid <- function(x, attrib, id1 = names(x)[1], id2 = names(x)[2]){
-
-  if(is.numeric(attrib)){
-    attrib_names = names(x)[attrib]
-  } else {
-    attrib_names = attrib
-    attrib = which(names(x) %in% attrib)
-  }
-
-  x_oneway <- x %>%
-    dplyr::mutate_(stplanr.id1 = id1,
-                   stplanr.id2 = id2,
-                   stplanr.key = ~paste(pmin(stplanr.id1, stplanr.id2), pmax(stplanr.id1, stplanr.id2))) %>%
-    dplyr::group_by_(quote(stplanr.key)) %>%
-    dplyr::mutate(is_two_way = ifelse(n() > 1, TRUE, FALSE)) %>%
-    dplyr::mutate_each("sum", attrib) %>%
-    dplyr::summarise_each_(funs("stplanr.first"),c(id1, id2, attrib, ~is_two_way)) %>%
-    dplyr::select_(quote(-stplanr.key))
-
-  return(x_oneway)
-
-}
-
-stplanr.first <- function(...) {
-  dplyr::first(...)
-}
\ No newline at end of file
+`%>%` <- dplyr::`%>%`
